# [Zope-tests] FAILED : ZTK 1.0dev / Python2.4.6 Linux 64bit

ccomb at free.fr ccomb at free.fr
Wed Feb 2 21:29:33 EST 2011

- Previous message: [Zope-tests] OK : Zope 3.4 Known Good Set / py2.4-64bit-linux
- Next message: [Zope-tests] FAILED : ZTK 1.0dev / Python2.5.5 Linux 64bit
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    FAILED : ZTK 1.0dev / Python2.4.6 Linux 64bit
    Build: http://buildbot.afpy.org/ztk1.0dev/builders/Python2.4.6%20Linux%2064bit/builds/156

    Build Reason: The Nightly scheduler named 'nightly' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://buildbot.afpy.org/ztk1.0dev/

- Previous message: [Zope-tests] OK : Zope 3.4 Known Good Set / py2.4-64bit-linux
- Next message: [Zope-tests] FAILED : ZTK 1.0dev / Python2.5.5 Linux 64bit
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list